Learn R Programming

CodelistGenerator (version 4.1.0)

domainDoc: Helper for consistent documentation of domain.

Description

Helper for consistent documentation of domain.

Arguments

domain

Character vector with one or more of the OMOP CDM domains. The results will be restricted to the given domains. Check the available domains in the database by running 'availableDomains()', or 'associatedDomains()' to explore the domains associated with a codelist. If NULL, all supported domains are included: Condition, Drug, Procedure, Device, Observation, and Measurement.