Learn R Programming

CodelistGenerator (version 4.1.0)

routeCategoryDoc: Helper for consistent documentation of routeCategory.

Description

Helper for consistent documentation of routeCategory.

Arguments

routeCategory

Only codes with the specified route will be returned. If NULL, descendant codes will be returned regardless of route category. Use 'availableRouteCategories()' to find the available route categories in the database, and 'associatedRouteCategories()' to get drug routs associated with a codelist.