Learn R Programming

CodelistGenerator (version 4.1.0)

xDocCohort: Helper for consistent documentation of x where input can be codelist or cohort.

Description

Helper for consistent documentation of x where input can be codelist or cohort.

Arguments

x

A codelist, codelist_with_details, or a concept_set. See newCodelist(), newCodelistWithDetails(), newConceptSetExpression() functions for more details. If set to NULL, the codelist associated with the cohort will be extracted