Run benchmark of codelistGenerator analyses
Source:R/benchmarkCodelistGenerator.R
benchmarkCodelistGenerator.RdRun benchmark of codelistGenerator analyses
Examples
# \donttest{
library(CodelistGenerator)
cdm <- mockVocabRef()
timings <- benchmarkCodelistGenerator(cdm)
#> Warning: - No matching Ingredient codes found for acetaminophen and codeine
#> Limiting to concept type, domains, and vocabularies of interest
#> Getting concepts to include
#> Adding concepts using synonymns
#> Adding codes from non-standard
#> ! No codes found for the given search strategy
#> Time taken: 0 minutes and 0 seconds
# }