A codelist, codelist_with_details, or a concept_set. See newCodelist(), newCodelistWithDetails(), newConceptSetExpression() functions for more details.
newCodelistName
Character vector with the name of the new codelist. If
NULL all codelists names will be combined.
keepOriginal
Whether to keep the original codelist (TRUE) or just return
the stratified ones (FALSE).
codelistsToJoin
Character vector with the names of the codelists to be
unioned.